package com.wd.workoffice.ui.activity.bat.work;

import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.alibaba.fastjson.JSON;
import com.wd.workoffice.R;
import com.wd.workoffice.app.BaseBean;
import com.wd.workoffice.app.WorkToolBarActivity;
import com.wd.workoffice.bean.LogisticBean;
import com.wd.workoffice.bean.LogisticDetailBean;
import com.wd.workoffice.bean.event.CheckLogisticEvent;
import com.wd.workoffice.bean.workEnum.PagePermissionType;
import com.wd.workoffice.retrofit.RtfUtils;
import com.wd.workoffice.retrofit.WorkObserver;
import com.wd.workoffice.ui.adapter.WorkLogisticDetailAdapter;
import com.wd.workoffice.util.MathUtils;
import com.wd.workoffice.util.WorkUtils;

import org.greenrobot.eventbus.EventBus;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import androidx.appcompat.app.AlertDialog;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;
import flexible.xd.android_base.network.rtfhttp.Transformer;
import io.reactivex.disposables.Disposable;

/**
 * 工作台 - 物流详情
 * author : flexible
 * email : lgd19940421@163.com
 * github: https://github.com/FlexibleXd
 **/
public class WorkLogisticsDetailActivity extends WorkToolBarActivity {
    @BindView(R.id.tv_refuse)
    TextView tvRefuse;
    @BindView(R.id.tv_agree)
    TextView tvAgree;
    @BindView(R.id.ll_bottom)
    LinearLayout llBottom;
    @BindView(R.id.tv_company)
    TextView tvCompany;
    @BindView(R.id.tv_desc)
    TextView tvDesc;
    @BindView(R.id.tv_receive_dep)
    TextView tvReceiveDep;
    @BindView(R.id.tv_process)
    TextView tvProcess;
    @BindView(R.id.rv_data)
    RecyclerView rvData;
    @BindView(R.id.tv_logistics_price)
    TextView tvLogisticsPrice;
    @BindView(R.id.tv_weight)
    TextView tvWeight;
    @BindView(R.id.tv_location)
    TextView tvLocation;
    @BindView(R.id.tv_ticket)
    TextView tvTicket;
    @BindView(R.id.tv_code)
    TextView tvCode;
    private List<LogisticDetailBean.RecordsBean> dataList;
    private WorkLogisticDetailAdapter dataAdapter;
    private Map<String, Object> param;
    private String orderType;

    @Override
    protected void initView() {
        ButterKnife.bind(this);
        rvData.setLayoutManager(new LinearLayoutManager(this, RecyclerView.VERTICAL, false));
    }

    @Override
    protected void initData() {
        LogisticBean.RecordsBean info = JSON.parseObject(getIntent().getStringExtra("info"), LogisticBean.RecordsBean.class);
        getData(info.getId() + "");
        tvCompany.setText(info.getLogisticsName());
        tvReceiveDep.setText(info.getReceiveDeptName());
        tvProcess.setText(WorkUtils.getOrderName(info.getProcessCode()));
        tvLogisticsPrice.setText(MathUtils.converData(info.getApplyAmount(),3));
        tvWeight.setText(String.valueOf(info.getTotalWeight()));
        tvLocation.setText(info.getDistributionSite());
        tvTicket.setText(info.getIssuingUnit());
        tvCode.setText(info.getInvoiceNumber());
        if (TextUtils.equals(info.getStatus(), "0")) {
            llBottom.setVisibility(View.VISIBLE);
            changePermission();
        } else {
            llBottom.setVisibility(View.GONE);
        }
        dataList = new ArrayList<>();
        dataAdapter = new WorkLogisticDetailAdapter(R.layout.item_logistics_detail, dataList);
        dataAdapter.bindToRecyclerView(rvData);
        param = new HashMap<>();
        param.put("id", info.getId());
        param.put("invoiceNumber", info.getInvoiceNumber());
        orderType = getIntent().getStringExtra("type");
    }

    private void changePermission() {
        boolean hasPermission = WorkUtils.hasPermission(PagePermissionType.LOGISTICS_UPDATE.getPermission());
        if (!hasPermission) {
            tvRefuse.setVisibility(View.GONE);
            tvAgree.setVisibility(View.GONE);
        }
    }

    private void getData(String id) {
        RtfUtils.getRtf().logisticsDetail(id).compose(Transformer.schedule()).subscribe(new WorkObserver<BaseBean>() {


            @Override
            public void doOnSubscribe(Disposable d) {
            }

            @Override
            public void onFail(String errorMsg) {
                hideLoading();
                toast(errorMsg);
            }

            @Override
            public void onSuccess(BaseBean data) {
                hideLoading();
                if (data.getCode() != 0) {
                    toast(data.getMessage());
                    return;
                }
                List<LogisticDetailBean.RecordsBean> dataBean = JSON.parseObject(data.getData().toString(), LogisticDetailBean.class).getRecords();
                dataList.addAll(dataBean);
                dataAdapter.notifyDataSetChanged();
            }
        });
    }

    @Override
    protected void initEvent() {
    }

    @Override
    protected int layoutId() {
        return R.layout.activity_work_logistics_detail;
    }


    @OnClick({R.id.tv_refuse, R.id.tv_agree})
    public void onViewClicked(View view) {
        switch (view.getId()) {
            case R.id.tv_refuse:
                checkDialog(2);
                break;
            case R.id.tv_agree:
                checkDialog(1);
                break;
        }
    }


    private void checkDialog(int status) {
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        View view = LayoutInflater.from(this).inflate(R.layout.view_check, null);
        TextView tvOk = view.findViewById(R.id.tv_ok);
        TextView tvDesc = view.findViewById(R.id.tv_desc);
        tvDesc.setText(status == 1 ? "通过" : "拒绝");
        TextView tvNum = view.findViewById(R.id.tv_num);
        TextView tvCancel = view.findViewById(R.id.tv_cancel);
        EditText etRemark = view.findViewById(R.id.et_content);
        WorkUtils.addNumListener(etRemark, tvNum);
        builder.setView(view);
        AlertDialog addCartDialog = builder.create();
        tvOk.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (status!=1 &&TextUtils.isEmpty(etRemark.getText().toString())) {
                    toast("请填写备注");
                    return;
                }
                check(status, etRemark.getText().toString());
                addCartDialog.dismiss();
            }
        });
        tvCancel.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                addCartDialog.dismiss();
            }
        });
        addCartDialog.show();
    }


    private void check(int status, String remark) {
        param.put("status", status);
        param.put("remark", remark);
        RtfUtils.getRtf().logisticsCheck(WorkUtils.convertMapToBody(param)).compose(Transformer.schedule()).subscribe(new WorkObserver<BaseBean>() {
            @Override
            public void doOnSubscribe(Disposable d) {
            }

            @Override
            public void onFail(String errorMsg) {
                hideLoading();
                toast(errorMsg);
            }

            @Override
            public void onSuccess(BaseBean data) {
                hideLoading();
                if (data.getCode() != 0) {
                    toast(data.getMessage());
                    return;
                }
                EventBus.getDefault().post(new CheckLogisticEvent());
                toast("操作成功");
                finish();

            }
        });
    }
}
